@@ -12,6 +12,7 @@ package Devel::DebugHooks::Commands;
 # TODO: enable/disable group of traps
 # TODO: implement option to show full/short sub options
 # TODO: split all code by two: user code and core
+# TODO: implement 'r n' to rewind n stack frames
 # TODO: implement distance 'T XXX'; Automatically sets XXX to the current line
 # TODO: implement 'b &' to set breakpoint to current sub
 # TODO: implement 'd code' command to debug given subroutine
@@ -28,7 +29,6 @@ package Devel::DebugHooks::Commands;
 # if() { statement; }
 # TODO: implement command to list all available packages
 # TODO: implement command to list all available subs in package ( DB::subs )
-# TODO: IT: closed variables are created at compile time. We do not see them when just eval at sub
 
 my $file_line =  qr/(?:(.+):)?(\d+|\.)/;
 
@@ -100,9 +100,7 @@ sub _list {
 		print $DB::OUT $file eq $run_file  &&  $line == $run_line ? '>>' : '  ';
 
 		print $DB::OUT DB::can_break( $file, $line ) ? 'x' : ' ';
-		(my $tmp =  $source->[ $line ]) =~ s/\t/    /g; #/
-		$tmp =  " $tmp"   if length $tmp > 1; # $tmp have at least "\n"
-		print $DB::OUT "$line:$tmp";
+		print $DB::OUT "$line: " . ($source->[ $line ] =~ s/\t/    /rg ); #/
 	}
 }
 
@@ -345,8 +343,7 @@ $DB::commands =  {
 		$curr_file   =  DB::state( 'file' );
 		$line_cursor =  DB::state( 'line' );
 
-		(my $tmp=DB::source()->[ $line_cursor ]) =~ s/^\s+//;
-		print $DB::OUT "$curr_file:$line_cursor    $tmp";
+		print $DB::OUT "$curr_file:$line_cursor    " .(DB::source()->[ $line_cursor ] =~ s/^(\s+)//r); #/
 
 		1;
 	},
@@ -672,13 +669,6 @@ $DB::commands =  {
 		$_->{ single } =  0   for @{ DB::state( 'stack' ) };
 
 
-		# The $DB::single will be restored when sub returns. So we set this flag
-		# to continue ignoring debugger traps
-		$DB::options{ NonStop } =  1;
-		# TODO: implement testcase
-		# $script = 'sub t{ #go }; t(); my $x';
-		# Stopped at 'my $x' w/o NonStop
-
 		return;
 	}
 
